gc3libs.application.turbomole — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.application.turbomole

Specialized support for TurboMol.

class `gc3libs.application.turbomole.` `TurbomoleApplication`(program, control, *others, **extra_args)

  Run TURBOMOLE’s program on the given control file. Any additional arguments are considered additional filenames to input files (e.g., the `coord` file) and copied to the execution directory.

  Parameters: | program (str) – Name of the TURBOMOLE’s program to run (e.g., `ridft`) control (str) – Path to a file in TURBOMOLE’s `control` format. others – Path(s) to additional input files.

class `gc3libs.application.turbomole.` `TurbomoleDefineApplication`(program, define_in, coord, *others, **extra_args)

  Run TURBOMOLE’s ‘define’ with the given define_in file as input, then run program on the control file produced.

  Any additional arguments are considered additional filenames to input files and copied to the execution directory.

  Parameters: | program (str) – Name of the TURBOMOLE’s program to run (e.g., `ridft`) define_in (str) – Path to a file containing keystrokes to pass

  as input to the ‘define’ program.

  Parameters: | coord (str) – Path to a file containing the molecule

  coordinates in TURBOMOLE’s format.

  Parameters: | others – Path(s) to additional input files.

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »